# gem

> Interact with the package manager for the Ruby programming language.

- Install latest version of a gem

`gem install {{gemname}}`

- Install specific version of a gem

`gem install {{gemname}} -v {{1.0.0}}`

- Update a gem

`gem update {{gemname}}`

- List all gems

`gem list`

- Uninstall a gem

`gem uninstall {{gemname}}`
